@@ -39,21 +39,25 @@ OC.L10N.register(
     "Email address" : "Direición de corréu electrónicu",
     "Cancel" : "Encaboxar",
     "General" : "Xeneral",
+    "Appearance" : "Aspeutu",
     "List" : "Llista",
     "Vertical split" : "DIxebra verical",
     "Horizontal split" : "Dixebra horizontal",
     "Sorting" : "Orde",
+    "Newest first" : "Primero lo nuevo",
+    "Oldest first" : "Primero lo antiguo",
     "Gravatar settings" : "Configuración de Gravatar",
     "Register" : "Rexistrase",
     "Shared with me" : "Compartióse conmigo",
+    "Security" : "Seguranza",
     "S/MIME" : "S/MIME",
-    "About" : "Tocante a",
     "Keyboard shortcuts" : "Atayos del tecláu",
     "Archive" : "Archivar",
     "Delete" : "Desaniciar",
     "Search" : "Buscar",
     "Send" : "Unviar",
     "Refresh" : "Anovar",
+    "About" : "Tocante a",
     "Ok" : "D'acuerdu",
     "Certificate updated" : "Anovóse'l certificáu",
     "Could not update certificate" : "Nun se pudo anovar el certificáu",
@@ -140,7 +144,6 @@ OC.L10N.register(
     "Yesterday" : "Ayeri",
     "Last week" : "La selmana anterior",
     "Last month" : "El mes anterior",
-    "Loading messages …" : "Cargando los mensaxes…",
     "Choose target folder" : "Escoyer la carpeta de destín",
     "No more submailboxes in here" : "Equí nun hai más sobandexes",
     "Important info" : "Información importante",
@@ -168,7 +171,6 @@ OC.L10N.register(
     "Show all folders" : "Amosar toles carpetes",
     "Collapse folders" : "Contrayer carpetes",
     "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
-    "Loading …" : "Cargando…",
     "All messages in mailbox will be deleted." : "Van desaniciase tolos mensaxes d'esta bandexa.",
     "Delete folder" : "Desaniciar la carpeta",
     "An error occurred, unable to rename the mailbox." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
@@ -227,7 +229,6 @@ OC.L10N.register(
     "Tag name cannot be empty" : "El nome de la etiqueta nun pue tar baleru",
     "An error occurred, unable to create the tag." : "Prodúxose un error, nun ye posible crear la bandexa de corréu.",
     "Add tag" : "Amestar una etiqueta",
-    "Saving tag …" : "Guardando la etiqueta…",
     "Task created" : "Creóse la xera",
     "Could not create task" : "Nun se pudo crear la xera",
     "Summarizing thread failed." : "El resume del filu falló.",
@@ -310,6 +311,9 @@ OC.L10N.register(
     "Error loading message" : "Hebo un error al cargar el mensaxe",
     "Redirect" : "Redirixir",
     "The link leads to %s" : "L'enllaz lleva a %s",
-    "Accounts" : "Cuentes"
+    "Accounts" : "Cuentes",
+    "Loading messages …" : "Cargando los mensaxes…",
+    "Loading …" : "Cargando…",
+    "Saving tag …" : "Guardando la etiqueta…"
 },
 "nplurals=2; plural=(n != 1);");
