@@ -20,6 +20,9 @@ OC.L10N.register(
     "Cancel" : "Nullañ",
     "General" : "Hollek",
     "List" : "Roll",
+    "Newest first" : "An hini nevesañ da gentañ",
+    "Oldest first" : "An hini kozhoñ da gentañ",
+    "Security" : "Surentez",
     "Delete" : "Dilemel",
     "Search" : "Klask",
     "Send" : "Kas",
@@ -48,7 +51,6 @@ OC.L10N.register(
     "Move" : "Diplasañ",
     "Remove account" : "Lemel ar c'hont",
     "Folder name" : "Anv teuliad",
-    "Loading …" : "O Kargañ ...",
     "The folder and all messages in it will be deleted." : "An teuliad a pep kemenadenn enhañ a vo lamet",
     "Delete folder" : "Diverkañ an teuliad",
     "Delete folder {name}" : "Lemel an teuliad {folderid}",
@@ -77,6 +79,7 @@ OC.L10N.register(
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "Accounts" : "Kontoù"
+    "Accounts" : "Kontoù",
+    "Loading …" : "O Kargañ ..."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
