@@ -95,7 +95,6 @@ OC.L10N.register(
     "Oldest first" : "Más antiguo primero",
     "Register" : "Registrar",
     "Security" : "Seguridad",
-    "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -107,6 +106,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
+    "About" : "Acerca",
     "Ok" : "Ok",
     "No certificate" : "Sin certificado",
     "Certificate updated" : "Certificado actualizado",
@@ -128,16 +128,12 @@ OC.L10N.register(
     "From" : "De",
     "Select account" : "Selecciona la cuenta",
     "To" : "A",
-    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
     "Cc" : "Cc",
     "Bcc" : "Cco",
     "Subject" : "Asunto",
-    "Subject …" : "Asunto...",
     "This message came from a noreply address so your reply will probably not be read." : "Este mensaje proviene de una dirección \"noreply\", por lo que probablemente no se lea tu respuesta.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Los siguientes destinatarios no tienen un certificado S/MIME: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Los siguientes destinatarios no tienen una clave PGP: {recipients}.",
-    "Write message …" : "Escribir mensaje...",
-    "Saving draft …" : "Guardando borrador...",
     "Error saving draft" : "Error al guardar el borrador",
     "Draft saved" : "Borrador guardado",
     "Save draft" : "Guardar borrador",
@@ -244,7 +240,6 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Last week" : "La semana pasada",
     "Last month" : "El mes pasado",
-    "Loading messages …" : "Cargando mensajes...",
     "Choose target folder" : "Selecciona la carpeta de destino.",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Los mensajes se marcarán automáticamente como importantes en función de los mensajes con los que interactúes o que marques como importantes. Al principio, es posible que debas cambiar manualmente la importancia para enseñar al sistema, pero mejorará con el tiempo.",
@@ -299,7 +294,6 @@ OC.L10N.register(
     "Collapse folders" : "Compactar carpetas",
     "_{total} message_::_{total} messages_" : ["{total} mensaje","{total} mensajes","{total} mensajes"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} sin leer de {total}","{unread} sin leer de {total}","{unread} sin leer de {total}"],
-    "Loading …" : "Loading …",
     "All messages in mailbox will be deleted." : "Se eliminarán todos los mensajes del buzón.",
     "Clear mailbox {name}" : "Limpiar buzón {name}",
     "An error occurred, unable to rename the mailbox." : "Se produjo un error, no se puede cambiar el nombre del buzón.",
@@ -344,7 +338,6 @@ OC.L10N.register(
     "Add to Contact" : "Agregar a Contactos",
     "New Contact" : "Nuevo contacto",
     "Copy to clipboard" : "Copiar al portapapeles",
-    "Contact name …" : "Nombre del contacto ...",
     "Add" : "Agregar",
     "Show less" : "Mostrar menos",
     "Show more" : "Mostrar más",
@@ -370,13 +363,11 @@ OC.L10N.register(
     "Save sieve settings" : "Guardar configuración de Sieve",
     "The syntax seems to be incorrect:" : "La sintaxis parece ser incorrecta:",
     "Save sieve script" : "Guardar script de Sieve",
-    "Signature …" : "Firma ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Tu firma tiene un tamaño mayor de 2 MB. Esto puede afectar el rendimiento de tu editor.",
     "Save signature" : "Guardar firma",
     "Place signature above quoted text" : "Colocar firma sobre el texto citado",
     "Message source" : "Origen del mensaje",
     "An error occurred, unable to rename the tag." : "Ocurrió un error, no se pudo cambiar el nombre de la etiqueta.",
-    "Saving new tag name …" : "Guardando nuevo nombre de etiqueta ...",
     "Set tag" : "Establecer etiqueta",
     "Unset tag" : "Quitar etiqueta",
     "Tag name is a hidden system tag" : "El nombre de la etiqueta es una etiqueta oculta del sistema",
@@ -384,7 +375,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Ocurrió un error, no se pudo crear la etiqueta.",
     "Add default tags" : "Agregar etiquetas predeterminadas",
     "Add tag" : "Agregar etiqueta",
-    "Saving tag …" : "Guardando etiqueta ...",
     "Task created" : "Tarea creada",
     "Could not create task" : "No se pudo crear la tarea",
     "No calendars with task list support" : "No hay calendarios con soporte de lista de tareas",
@@ -587,6 +577,16 @@ OC.L10N.register(
     "Register as application for mail links" : "Registrarse como aplicación para enlaces de correo",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
     "Trusted senders" : "Remitentes de confianza",
-    "Manage S/MIME certificates" : "Administrar certificados S/MIME"
+    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
+    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
+    "Subject …" : "Asunto...",
+    "Write message …" : "Escribir mensaje...",
+    "Saving draft …" : "Guardando borrador...",
+    "Loading messages …" : "Cargando mensajes...",
+    "Loading …" : "Loading …",
+    "Contact name …" : "Nombre del contacto ...",
+    "Signature …" : "Firma ...",
+    "Saving new tag name …" : "Guardando nuevo nombre de etiqueta ...",
+    "Saving tag …" : "Guardando etiqueta ..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
