@@ -21,7 +21,7 @@ OC.L10N.register(
     "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Saatja kasutab muudetud e-postiaadressi %1$s oma tavalise %2$s aadressi asemel",
     "Sent date is in the future" : "Saatmise kuupäev on tulevikus",
     "Some addresses in this message are not matching the link text" : "Mõned selle kirja aadressid ei vasta lingi tekstile",
-    "Reply-To email: %1$s  is different from the sender email: %2$s" : "Vastamiseks mõeldud e-posti aadress %1$s on erinev saatja aadressist %2$s",
+    "Reply-To email: %1$s is different from sender email: %2$s" : "Vastamiseks mõeldud e-posti aadress: %1$s on erinev saatja aadressist %2$s",
     "Mail connection performance" : "E-postiteenuse ühenduse jõudlus",
     "💌 A mail app for Nextcloud" : "💌 E-postirakendus Nextcloudi jaoks",
     "Your session has expired. The page will be reloaded." : "Sinu sessioon on aegunud. Leht saab olema uuesti laaditud.",
@@ -469,7 +469,7 @@ OC.L10N.register(
     "Failed to save draft" : "Mustandi salvestamine ei õnnestu",
     "attachment" : "manus",
     "attached" : "manus on lisatud",
-    "No sent folder configured. Please pick one in the account settings." : "Saadetud kirjade kaust on seadistamata. Palun see seda kasutajakonto seadistustes.",
+    "No \"sent\" folder configured. Please pick one in the account settings." : "Saadetud kirjade kaust on seadistamata. Palun see seda kasutajakonto seadistustes.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Sa üritad saata kirja, kus saaja ja koopia välja on hiidpalju aadresse. Kirjasaajate privaatsuse ja mugavuse nimel palun kasuta pimekoopia välja.",
     "Your message has no subject. Do you want to send it anyway?" : "Sinu e-kirjal puudub teema. Kas sa kindlasti soovid seda saata?",
     "You mentioned an attachment. Did you forget to add it?" : "Sa mainisid, et tahad manuse lisada. Kas see ununes?",
