@@ -98,7 +98,6 @@ OC.L10N.register(
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Gestisci certificati",
     "Mailvelope" : "Mailvelope",
-    "About" : "Informazioni",
     "Keyboard shortcuts" : "Scorciatoie da tastiera",
     "Compose new message" : "Componi nuovo messaggio",
     "Newer message" : "Messaggio più recente",
@@ -110,6 +109,7 @@ OC.L10N.register(
     "Search" : "Cerca",
     "Send" : "Invia",
     "Refresh" : "Aggiorna",
+    "About" : "Informazioni",
     "Ok" : "Ok",
     "No certificate" : "Nessun certificato",
     "Certificate updated" : "Certificato aggiornato",
@@ -127,15 +127,11 @@ OC.L10N.register(
     "From" : "Da",
     "Select account" : "Seleziona account",
     "To" : "A",
-    "Contact or email address …" : "Contatto o indirizzo email...",
     "Cc" : "Cc",
     "Bcc" : "Ccn",
     "Subject" : "Oggetto",
-    "Subject …" : "Oggetto...",
     "This message came from a noreply address so your reply will probably not be read." : "Nota che il messaggio è arrivato da un indirizzo noreply, perciò la tua risposta non sarà probabilmente letta.",
     "The following recipients do not have a PGP key: {recipients}." : "I seguenti destinatari non hanno una chiave PGP: {recipients}.",
-    "Write message …" : "Scrivi messaggio...",
-    "Saving draft …" : "Salvataggio bozza…",
     "Draft saved" : "Bozza salvata",
     "Save draft" : "Salva bozza",
     "Discard & close draft" : "Scarta e chiudi bozza",
@@ -248,7 +244,6 @@ OC.L10N.register(
     "Today" : "Ogg",
     "Last week" : "Ultima settimana",
     "Last month" : "Ultimo mese",
-    "Loading messages …" : "Caricamento messaggi...",
     "Choose target folder" : "Scegli la cartella di destinazione",
     "No more submailboxes in here" : "Qui non ci sono altre sotto-caselle di posta",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "I messaggi saranno automaticamente contrassegnati come importanti in base ai messaggi con cui hai interagito o contrassegnati come importanti. All'inizio potresti dover cambiare manualmente l'importanza per addestrare il sistema, ma migliorerà nel tempo.",
@@ -300,7 +295,7 @@ OC.L10N.register(
     "Collapse folders" : "Contrai le cartelle",
     "_{total} message_::_{total} messages_" : ["{total} messaggio","{total} messaggi","{total} messaggi"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non letto di {total}","{unread} non letti di {total}","{unread} non letti di {total}"],
-    "Loading …" : "Caricamento in corso...",
+    "Loading …" : "Caricamento in corso...",
     "The folder and all messages in it will be deleted." : "La cartella e tutti i messaggi in essa saranno eliminati.",
     "Delete folder" : "Elimina cartella",
     "Delete folder {name}" : "Elimina cartella {name}",
@@ -345,7 +340,6 @@ OC.L10N.register(
     "Add to Contact" : "Aggiungi ai contatti",
     "New Contact" : "Nuovo contatto",
     "Copy to clipboard" : "Copia negli appunti",
-    "Contact name …" : "Nome contatto …",
     "Add" : "Aggiungi",
     "Show less" : "Mostra meno",
     "Show more" : "Mostra più",
@@ -373,19 +367,16 @@ OC.L10N.register(
     "Sieve Password" : "Password Sieve",
     "Save sieve settings" : "Salva impostazione Sieve",
     "Save sieve script" : "Salva script Sieve",
-    "Signature …" : "Firma...",
     "Save signature" : "Salva firma",
     "Place signature above quoted text" : "Posiziona la firma sopra il testo citato",
     "Message source" : "Sorgente del messaggio",
     "An error occurred, unable to rename the tag." : "Si è verificato un errore, impossibile rinominare l'etichetta.",
     "Edit name or color" : "Modifica nome o colore",
-    "Saving new tag name …" : "Salvataggio nuovo nome della etichetta...",
     "Delete tag" : "Elimina etichetta",
     "Tag already exists" : "L'etichetta esiste già",
     "An error occurred, unable to create the tag." : "Si è verificato un errore, impossibile creare l'etichetta.",
     "Add default tags" : "Aggiungi etichette predefiniti",
     "Add tag" : "Aggiungi etichetta",
-    "Saving tag …" : "Salvataggio etichetta …",
     "Task created" : "Attività creata",
     "Could not create task" : "Impossibile creare l'attività",
     "Could not load your message thread" : "Impossibile caricare la tua discussione",
@@ -573,6 +564,16 @@ OC.L10N.register(
     "Register as application for mail links" : "Registra come applicazione per i collegamenti di posta",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Consenti all'applicazione di raccogliere dati sulle tue interazioni. Sulla base di questi dati, l'applicazione si adatterà alle tue preferenze. I dati saranno archiviati solo localmente.",
     "Trusted senders" : "Mittenti affidabili",
-    "Manage S/MIME certificates" : "Gestisci i certificati S/MIME"
+    "Manage S/MIME certificates" : "Gestisci i certificati S/MIME",
+    "Contact or email address …" : "Contatto o indirizzo email...",
+    "Subject …" : "Oggetto...",
+    "Write message …" : "Scrivi messaggio...",
+    "Saving draft …" : "Salvataggio bozza…",
+    "Loading messages …" : "Caricamento messaggi...",
+    "Loading …" : "Caricamento in corso...",
+    "Contact name …" : "Nome contatto …",
+    "Signature …" : "Firma...",
+    "Saving new tag name …" : "Salvataggio nuovo nome della etichetta...",
+    "Saving tag …" : "Salvataggio etichetta …"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
