@@ -150,16 +150,12 @@ OC.L10N.register(
     "Select account" : "계정 선택",
     "To" : "받는사람",
     "Select recipient" : "수신자 지정",
-    "Contact or email address …" : "연락처 또는 이메일 주소 ...",
     "Cc" : "참조",
     "Bcc" : "숨은참조",
     "Subject" : "제목",
-    "Subject …" : "제목...",
     "This message came from a noreply address so your reply will probably not be read." : "발신 전용 주소에서 보낸 메시지이므로 답장이 전달되지 않을 수 있습니다.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "다음 받는이가 S/MIME 인증서를 가지고 있지 않습니다: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "다음의 받는이는 PGP key가 없습니다:{recipients}.",
-    "Write message …" : "메시지 작성중...",
-    "Saving draft …" : "초안 저장 중...",
     "Error saving draft" : "초안을 저장하는 중에 오류가 발생했습니다.",
     "Draft saved" : "초안 저장됨",
     "Save draft" : "초안 저장",
@@ -282,7 +278,6 @@ OC.L10N.register(
     "Today" : "오늘",
     "Yesterday" : "어제",
     "Last week" : "지난 주",
-    "Loading messages …" : "메시지를 불러오는 중 ...",
     "Choose target folder" : "폴더 선택",
     "No more submailboxes in here" : "더 이상의 하위 편지함 없음",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "사용자의 메시지 상호작용, 중요 표시 정보 등을 바탕으로 특정 메시지가 자동으로 중요 표시됩니다. 초기 단계에서는 시스템의 학습을 위해 사용자가 중요 여부를 수동으로 변경하게 될 수 있으나, 이는 점차 개선될 것입니다.",
@@ -341,7 +336,6 @@ OC.L10N.register(
     "Collapse folders" : "폴더 접기",
     "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 개 중 {unread} 개 읽지 않음"],
-    "Loading …" : "불러오는 중 …",
     "All messages in mailbox will be deleted." : "편지함에 있는 모든 메시지가 삭제됩니다",
     "Clear mailbox {name}" : "편지함 {name} 비우기",
     "Delete folder" : "폴더 삭제",
@@ -394,7 +388,6 @@ OC.L10N.register(
     "Add to Contact" : "연락처 추가",
     "New Contact" : "새 연락처",
     "Copy to clipboard" : "클립보드로 복사",
-    "Contact name …" : "연락처 이름 ...",
     "Add" : "추가",
     "Show less" : "적게 보기",
     "Show more" : "더 보기",
@@ -425,14 +418,12 @@ OC.L10N.register(
     "Save sieve settings" : "Sieve 설정 저장",
     "The syntax seems to be incorrect:" : "문법이 잘못된 것 같습니다:",
     "Save sieve script" : "Sieve 스크립트 저장",
-    "Signature …" : "서명 …",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "서명이 2 MB를 초과합니다. 편집기의 성능에 영향을 미칠 수 있습니다.",
     "Save signature" : "서명 저장",
     "Place signature above quoted text" : "인용 문구 상단에 서명 삽입",
     "Message source" : "메시지 원본",
     "An error occurred, unable to rename the tag." : "오류가 발생하여 태그 이름을 변경할 수 없습니다",
     "Edit name or color" : "이름 또는 색깔 편집",
-    "Saving new tag name …" : "새 태그명 저장 ...",
     "Delete tag" : "태그 삭제",
     "Set tag" : "태그 설정",
     "Unset tag" : "태그 설정 해제",
@@ -442,7 +433,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "오류가 발생하여 태그 이름을 생성할 수 없습니다",
     "Add default tags" : "기본 태그 추가",
     "Add tag" : "태그 추가",
-    "Saving tag …" : "태그 저장하는 중 ...",
     "Task created" : "작업이 생성됨",
     "Could not create task" : "작업을 만들 수 없음",
     "No calendars with task list support" : "작업 목록을 지원하는 달력 없음",
@@ -662,6 +652,16 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
     "Trusted senders" : "신뢰할 수 있는 발신자",
     "Internal addresses" : "내부 주소",
-    "Manage S/MIME certificates" : "S/MIME 인증서 관리"
+    "Manage S/MIME certificates" : "S/MIME 인증서 관리",
+    "Contact or email address …" : "연락처 또는 이메일 주소 ...",
+    "Subject …" : "제목...",
+    "Write message …" : "메시지 작성중...",
+    "Saving draft …" : "초안 저장 중...",
+    "Loading messages …" : "메시지를 불러오는 중 ...",
+    "Loading …" : "불러오는 중 …",
+    "Contact name …" : "연락처 이름 ...",
+    "Signature …" : "서명 …",
+    "Saving new tag name …" : "새 태그명 저장 ...",
+    "Saving tag …" : "태그 저장하는 중 ..."
 },
 "nplurals=1; plural=0;");
