@@ -89,7 +89,6 @@ OC.L10N.register(
     "Security" : "Saugumas",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Tvarkyti liudijimus",
-    "About" : "Apie",
     "Keyboard shortcuts" : "Spartieji klavišai",
     "Compose new message" : "Rašyti naują laišką",
     "Newer message" : "Naujesni laiškai",
@@ -101,6 +100,7 @@ OC.L10N.register(
     "Search" : "Ieškoti",
     "Send" : "Siųsti",
     "Refresh" : "Įkelti iš naujo",
+    "About" : "Apie",
     "Ok" : "Gerai",
     "Certificate updated" : "Liudijimas atnaujintas",
     "Could not update certificate" : "Nepavyko atnaujinti liudijimo",
@@ -116,16 +116,12 @@ OC.L10N.register(
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
     "To" : "Kam",
-    "Contact or email address …" : "Adresatas ar el. pašto adresas…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Tema",
-    "Subject …" : "Tema…",
     "This message came from a noreply address so your reply will probably not be read." : "Šis laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Šie gavėjai neturi S/MIME liudijimo: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Šie gavėjai neturi PGP rakto: {recipients}.",
-    "Write message …" : "Rašykite laišką…",
-    "Saving draft …" : "Įrašomas juodraštis…",
     "Error saving draft" : "Klaida įrašant juodraštį",
     "Draft saved" : "Juodraštis įrašytas",
     "Save draft" : "Įrašyti juodraštį",
@@ -210,7 +206,6 @@ OC.L10N.register(
     "Today" : "Šiandien",
     "Last week" : "Praeitą savaitę",
     "Last month" : "Praeitą mėnesį",
-    "Loading messages …" : "Įkeliami laiškai…",
     "Choose target folder" : "Pasirinkite paskirties aplanką",
     "Important info" : "Svarbi informacija",
     "Other" : "Kita",
@@ -257,7 +252,6 @@ OC.L10N.register(
     "Collapse folders" : "Suskleisti aplankus",
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
-    "Loading …" : "Įkeliama…",
     "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
     "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
     "The folder and all messages in it will be deleted." : "Aplankas ir visi jame esantys laiškai bus ištrinti.",
@@ -300,7 +294,6 @@ OC.L10N.register(
     "Contacts with this address" : "Adresatai turintys šį adresą",
     "New Contact" : "Naujas adresatas",
     "Copy to clipboard" : "Kopijuoti į iškarpinę",
-    "Contact name …" : "Adresato vardas…",
     "Add" : "Pridėti",
     "Show less" : "Rodyti mažiau",
     "Show more" : "Rodyti daugiau",
@@ -311,7 +304,6 @@ OC.L10N.register(
     "Select tags" : "Pasirinkti žymas",
     "Last 7 days" : "Paskutinės 7 dienos",
     "Custom" : "Tinkinti",
-    "Signature …" : "Parašas…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Jūsų parašas yra didesnis nei 2 MB. Tai gali paveikti redaktoriaus našumą.",
     "Save signature" : "Įrašyti parašą",
     "Message source" : "Pirminis laiško kodas",
@@ -323,7 +315,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymos.",
     "Add default tags" : "Pridėti numatytąsias žymas",
     "Add tag" : "Pridėti žymą",
-    "Saving tag …" : "Įrašoma žyma…",
     "Task created" : "Užduotis sukurta",
     "Could not create task" : "Nepavyko sukurti užduoties",
     "Not found" : "Nerasta",
@@ -454,6 +445,15 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
     "Trusted senders" : "Patikimi siuntėjai",
     "Internal addresses" : "Vidiniai adresai",
-    "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus"
+    "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus",
+    "Contact or email address …" : "Adresatas ar el. pašto adresas…",
+    "Subject …" : "Tema…",
+    "Write message …" : "Rašykite laišką…",
+    "Saving draft …" : "Įrašomas juodraštis…",
+    "Loading messages …" : "Įkeliami laiškai…",
+    "Loading …" : "Įkeliama…",
+    "Contact name …" : "Adresato vardas…",
+    "Signature …" : "Parašas…",
+    "Saving tag …" : "Įrašoma žyma…"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
