@@ -64,7 +64,6 @@ OC.L10N.register(
     "Select account" : "Atlasīt kontu",
     "To" : "Līdz",
     "Subject" : "Temats",
-    "Write message …" : "Rakstiet ziņu...",
     "Add attachment from Files" : "Pievienot pielikumu no Datnēm",
     "Enter a date" : "Ievadiet datumu",
     "Choose" : "Izvēlēties",
@@ -92,6 +91,7 @@ OC.L10N.register(
     "Remove" : "Noņemt",
     "email" : "e-pasts",
     "Today" : "Šodien",
+    "Could not open folder" : "Nevarēja atvērt mapi",
     "Other" : "Cits",
     "The sender of this message has asked to be notified when you read this message." : "Šī ziņojuma sūtītājs ir norādījis, ka vēlas saņemt paziņojumu par šī ziņojuma izlasīšanu.",
     "Forward" : "Turpināt",
@@ -113,7 +113,6 @@ OC.L10N.register(
     "Saving" : "Saglabā",
     "Show all folders" : "Rādīt visas mapes",
     "Collapse folders" : "Sakļaut mapes",
-    "Loading …" : "Ielādē…",
     "Delete folder" : "Izdzēst mapi",
     "An error occurred, unable to rename the mailbox." : "Atgadījās kļūda, nevar pārdēvēt pastkasti.",
     "Rename" : "Pārdēvēt",
@@ -124,6 +123,7 @@ OC.L10N.register(
     "Retry" : "Mēģināt vēlreiz",
     "Autoresponder follows system settings" : "Automātiskais atbildētājs ievēro sistēmas iestatījumus",
     "Message" : "Ziņojums",
+    "Could not open outbox" : "Nevarēja atvērt izsūtni",
     "Copy to clipboard" : "Kopēt starpliktuvē",
     "Add" : "Pievienot",
     "Show more" : "Parādīt vairāk",
@@ -184,6 +184,8 @@ OC.L10N.register(
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
     "Continue to %s" : "Turpināt %s",
-    "Accounts" : "Konti"
+    "Accounts" : "Konti",
+    "Write message …" : "Rakstiet ziņu...",
+    "Loading …" : "Ielādē…"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
