@@ -62,7 +62,6 @@ OC.L10N.register(
     "Register" : "Registar",
     "Shared with me" : "Partilhadas comigo",
     "Security" : "Segurança",
-    "About" : "Sobre",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Compose new message" : "Compor nova mensagem",
     "Archive" : "Arquivar",
@@ -70,17 +69,14 @@ OC.L10N.register(
     "Search" : "Pesquisar",
     "Send" : "Enviar",
     "Refresh" : "Atualizar",
+    "About" : "Sobre",
     "Ok" : "CONFIRMAR",
     "From" : "De",
     "Select account" : "Selecionar uma conta",
     "To" : "Para",
-    "Contact or email address …" : "Contacto ou endereço de email",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Assunto",
-    "Subject …" : "Assunto...",
-    "Write message …" : "Nova mensagem...",
-    "Saving draft …" : "A guardar rascunho ...",
     "Draft saved" : "Rascunho guardado",
     "Enable formatting" : "Ativar formatação",
     "Upload attachment" : "Carregar anexo",
@@ -153,7 +149,6 @@ OC.L10N.register(
     "Move down" : "Mover para baixo",
     "Show all folders" : "Mostrar todas as pastas",
     "Collapse folders" : "Ocultar pastas",
-    "Loading …" : "A carregar...",
     "Delete folder" : "Apagar pasta",
     "Mark all as read" : "Marcar todas como lidas",
     "Rename" : "Renomear",
@@ -172,7 +167,6 @@ OC.L10N.register(
     "Add to Contact" : "Adicionar aos contactos",
     "New Contact" : "Novo contacto",
     "Copy to clipboard" : "Copiar para área de transferência",
-    "Contact name …" : "Nome do contacto...",
     "Add" : "Adicionar",
     "Show less" : "Mostrar menos",
     "Clear" : "Limpar",
@@ -182,7 +176,6 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Last 7 days" : "Últimos 7 dias",
     "Custom" : "Personalizado",
-    "Signature …" : "Assinatura...",
     "Save signature" : "Guardar assinatura",
     "Message source" : "Fonte da mensagem",
     "Tag already exists" : "A etiqueta já existe",
@@ -249,6 +242,13 @@ OC.L10N.register(
     "Oldest" : "Oldest",
     "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
     "Register as application for mail links" : "Registar como aplicação para ligações de correio",
-    "Trusted senders" : "Remetentes confiáveis"
+    "Trusted senders" : "Remetentes confiáveis",
+    "Contact or email address …" : "Contacto ou endereço de email",
+    "Subject …" : "Assunto...",
+    "Write message …" : "Nova mensagem...",
+    "Saving draft …" : "A guardar rascunho ...",
+    "Loading …" : "A carregar...",
+    "Contact name …" : "Nome do contacto...",
+    "Signature …" : "Assinatura..."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
