@@ -100,7 +100,6 @@ OC.L10N.register(
     "Register" : "Înregistrează-te",
     "Shared with me" : "Partajat cu mine",
     "Security" : "Securitate",
-    "About" : "Despre",
     "Keyboard shortcuts" : "Scurtături din tastatură",
     "Compose new message" : "Compuneți mesaje noi",
     "Newer message" : "Mesaj mai recent",
@@ -112,6 +111,7 @@ OC.L10N.register(
     "Search" : "Caută",
     "Send" : "Trimite",
     "Refresh" : "Reîmprospătează",
+    "About" : "Despre",
     "Ok" : "Ok",
     "No certificate" : "Niciun certificat",
     "Certificate updated" : "Certificatul a fost actualizat",
@@ -128,15 +128,11 @@ OC.L10N.register(
     "From" : "De la",
     "Select account" : "Selectează cont",
     "To" : "Către",
-    "Contact or email address …" : "Contact sau adresă email ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Subiect",
-    "Subject …" : "Subiect ...",
     "This message came from a noreply address so your reply will probably not be read." : "Acest mesaj a sosit de la o adresă noreply, astfel că răspunsul tău s-ar putea să nu fie citit.",
     "The following recipients do not have a PGP key: {recipients}." : "Următorii destinatari nu au o cheie PGP: {recipients}.",
-    "Write message …" : "Scrie mesajul ...",
-    "Saving draft …" : "Se salvează mesajul ...",
     "Error saving draft" : "Eroare la salvarea schiței",
     "Draft saved" : "Mesaj salvat",
     "Save draft" : "Salvează schița",
@@ -255,7 +251,6 @@ OC.L10N.register(
     "email" : "email",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nu aveți permisiunea să mutați mesajul în folderul de arhivare și/sau șterge mesajul din folderul curent",
     "Today" : "Azi",
-    "Loading messages …" : "Se încarcă mesajele ...",
     "Choose target folder" : "Alege directorul destinație",
     "No more submailboxes in here" : "Nu mai sunt subfoldere",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mesajul va fi marcat automat ca important în funcție de mesajele cu care ați interacționat sau pe care le-ați marcat ca importante. La început ar trebui să setați manual importanța pentru antrenarea sistemului, dar aceasta se va îmbunătăți în timp.",
@@ -311,7 +306,6 @@ OC.L10N.register(
     "Show all folders" : "Arată toate directoarele",
     "_{total} message_::_{total} messages_" : ["{total} mesaj","{total} mesaje","{total} mesaje"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} necitit din {total}","{unread} necitite din {total}","{unread} necitite din {total}"],
-    "Loading …" : "Se încarcă…",
     "All messages in mailbox will be deleted." : "Vor fi șterse toate mesajele din acest folder",
     "Clear mailbox {name}" : "Golește folderul {name}",
     "An error occurred, unable to rename the mailbox." : "Eroare la redenumirea mailbox.",
@@ -359,7 +353,6 @@ OC.L10N.register(
     "Add to Contact" : "Adaugă la Contacte",
     "New Contact" : "Persoană de contact nouă",
     "Copy to clipboard" : "Copiază în clipboard",
-    "Contact name …" : "Nume contact ...",
     "Add" : "Adaugă",
     "Clear" : "Șterge ",
     "Close" : "Închide",
@@ -382,14 +375,12 @@ OC.L10N.register(
     "Enable mail body search" : "Activează căutarea în textul mesajelor",
     "Custom" : "Particularizat",
     "The syntax seems to be incorrect:" : "Sintaxa pare incorectă:",
-    "Signature …" : "Semnătura ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Semnătura este mai mare de 2 MB. Aceasta poate afecta performanța editorului.",
     "Save signature" : "Salvează semnătura",
     "Place signature above quoted text" : "Plasează semnătura deasupra textului citat",
     "Message source" : "Sursa mesajului",
     "An error occurred, unable to rename the tag." : "Eroare la redenumirea etichetei.",
     "Edit name or color" : "Editează numele sau culoarea",
-    "Saving new tag name …" : "Se salvează noul nume al etichetei ...",
     "Delete tag" : "Șterge eticheta",
     "Set tag" : "Setează eticheta",
     "Unset tag" : "Deselectează eticheta",
@@ -398,7 +389,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Eroare la crearea etichetei.",
     "Add default tags" : "Adaugă etichetele implicite",
     "Add tag" : "Adaugă etichetă",
-    "Saving tag …" : "Se salvează eticheta ...",
     "Task created" : "Sarcina a fost creată",
     "Could not create task" : "Sarcina nu a putut fi creată",
     "No calendars with task list support" : "Nu există calendare cu suport pentru liste de sarcini",
@@ -515,6 +505,16 @@ OC.L10N.register(
     "Register as application for mail links" : "Înregistrează ca aplicație pentru\nlink-urile de mail",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permiteți aplicației să colecteze date despre interacțiunile dumneavoastră. Aplicația se va adapta preferințelor dumneavoastră în funcție de aceste date. Datele sunt stocate doar local.",
     "Trusted senders" : "Expeditori de încredere",
-    "Manage S/MIME certificates" : "Administrează certificatele  S/MIME"
+    "Manage S/MIME certificates" : "Administrează certificatele  S/MIME",
+    "Contact or email address …" : "Contact sau adresă email ...",
+    "Subject …" : "Subiect ...",
+    "Write message …" : "Scrie mesajul ...",
+    "Saving draft …" : "Se salvează mesajul ...",
+    "Loading messages …" : "Se încarcă mesajele ...",
+    "Loading …" : "Se încarcă…",
+    "Contact name …" : "Nume contact ...",
+    "Signature …" : "Semnătura ...",
+    "Saving new tag name …" : "Se salvează noul nume al etichetei ...",
+    "Saving tag …" : "Se salvează eticheta ..."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
