@@ -64,7 +64,6 @@ OC.L10N.register(
     "Register" : "Registra",
     "Shared with me" : "Cumpartzidos cun megus",
     "Security" : "Seguresa",
-    "About" : "In contu de",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Compose new message" : "Iscrie messàgiu nou",
     "Newer message" : "Messàgiu prus reghente",
@@ -76,20 +75,17 @@ OC.L10N.register(
     "Search" : "Chirca",
     "Send" : "Imbia",
     "Refresh" : "Agiorna",
+    "About" : "In contu de",
     "Ok" : "AB",
     "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
     "From" : "Dae",
     "Select account" : "Seletziona contu",
     "To" : "A",
-    "Contact or email address …" : "Cuntatu o indiritzu de posta ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Ogetu",
-    "Subject …" : "Ogetu",
     "This message came from a noreply address so your reply will probably not be read." : "Custu messàgiu est arribadu dae unu indiritzu chena resposta, tando est fàtzile chi sa resposta tua no s'at a lèghere.",
     "The following recipients do not have a PGP key: {recipients}." : "Custas persones destinatàrias no tenent una crae PGP: {recipients}.",
-    "Write message …" : "Iscrie messàgiu ...",
-    "Saving draft …" : "Sarvende sa brutacòpia ...",
     "Draft saved" : "Brutacòpia sarvada",
     "Enable formatting" : "Ativa formatatzione",
     "Upload attachment" : "Càrriga alligongiadu",
@@ -202,7 +198,6 @@ OC.L10N.register(
     "Move down" : "Tràmuda fache a bàsciu",
     "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non lèghidos de {total}","{unread} unread of {total}"],
-    "Loading …" : "Carrrighende …",
     "Delete folder" : "Cantzella sa cartella",
     "An error occurred, unable to rename the mailbox." : "B'at àpidu un'errore, no at fatu a torrare a numenare sa casella de posta.",
     "Mark all as read" : "Marca totu comente lèghidu",
@@ -225,7 +220,6 @@ OC.L10N.register(
     "Add to Contact" : "Agiunghe a Cuntatu",
     "New Contact" : "Cuntatu nou",
     "Copy to clipboard" : "Còpia in is punta de billete",
-    "Contact name …" : "Nùmene de su cuntatu ...",
     "Add" : "Agiunghe",
     "Show less" : "Mustra prus pagu",
     "Show more" : "Mustra de prus",
@@ -242,14 +236,11 @@ OC.L10N.register(
     "Sieve Password" : "Crae Sieve",
     "Save sieve settings" : "Sarva cunfiguratzione sieve",
     "Save sieve script" : "Sarva cumandos sieve",
-    "Signature …" : "Firma ...",
     "Save signature" : "Sarva firma",
     "Place signature above quoted text" : "Pone sa firma subra su testu tzitadu",
     "Message source" : "Fonte de su messàgiu",
-    "Saving new tag name …" : "Sarvende nùmene de eticheta nou...",
     "An error occurred, unable to create the tag." : "B'at àpidu un'errore, no faghet a creare s'eticheta.",
     "Add tag" : "Agiunghe eticheta",
-    "Saving tag …" : "Sarvende s'eticheta ...",
     "Could not load your message thread" : "No at fatu a carrigare su messàgiu tuo in sa dibata",
     "Not found" : "No agatadu",
     "Unsubscribe" : "Disiscrie·ti",
@@ -360,6 +351,15 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
     "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
-    "Trusted senders" : "Imbiantes afidàbiles"
+    "Trusted senders" : "Imbiantes afidàbiles",
+    "Contact or email address …" : "Cuntatu o indiritzu de posta ...",
+    "Subject …" : "Ogetu",
+    "Write message …" : "Iscrie messàgiu ...",
+    "Saving draft …" : "Sarvende sa brutacòpia ...",
+    "Loading …" : "Carrrighende …",
+    "Contact name …" : "Nùmene de su cuntatu ...",
+    "Signature …" : "Firma ...",
+    "Saving new tag name …" : "Sarvende nùmene de eticheta nou...",
+    "Saving tag …" : "Sarvende s'eticheta ..."
 },
 "nplurals=2; plural=(n != 1);");
