@@ -98,7 +98,6 @@ OC.L10N.register(
     "Shared with me" : "V souporabi z mano",
     "Security" : "Varnostna opozorila",
     "Manage certificates" : "Upravljanje s potrdili",
-    "About" : "O meni",
     "Keyboard shortcuts" : "Tipkovne bližnjice",
     "Compose new message" : "Novo sporočilo",
     "Newer message" : "Novejše sporočilo",
@@ -110,6 +109,7 @@ OC.L10N.register(
     "Search" : "Iskanje",
     "Send" : "Pošlji",
     "Refresh" : "Osveži",
+    "About" : "O meni",
     "Ok" : "Sprejemljivo",
     "No certificate" : "Ni potrdil",
     "Certificate updated" : "Potrdilo je posodobljeno",
@@ -130,16 +130,12 @@ OC.L10N.register(
     "Select account" : "Izbor računa",
     "To" : "Za",
     "Select recipient" : "Izbor prejemnika",
-    "Contact or email address …" : "Stik ali elektronski naslov ...",
     "Cc" : "Kp",
     "Bcc" : "Skp",
     "Subject" : "Zadeva",
-    "Subject …" : "Zadeva ...",
     "This message came from a noreply address so your reply will probably not be read." : "Sporočilo je bilo poslano z naslova, ki ni namenjen odgovarjanju, zato odgovor najverjetneje ne bo prispel do naslovnika.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Navedeni uporabniki nimajo ustreznega potrdila S/MIME: {recipients}",
     "The following recipients do not have a PGP key: {recipients}." : "Nekateri prejemniki so brez ključa PGP: {recipients}.",
-    "Write message …" : "Besedilo sporočila ...",
-    "Saving draft …" : "Poteka shranjevanje osnutka ...",
     "Error saving draft" : "Napaka shranjevanja osnutka",
     "Draft saved" : "Osnutek je shranjen",
     "Save draft" : "Shrani osnutek",
@@ -249,7 +245,6 @@ OC.L10N.register(
     "Today" : "Danes",
     "Last week" : "Zadnji teden",
     "Last month" : "Zadnji mesec",
-    "Loading messages …" : "Poteka nalaganje sporočil ...",
     "Choose target folder" : "Izbor ciljne mape",
     "No more submailboxes in here" : "V tem predalu ni drugih predalov",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Sporočila bodo samodejno označena kot pomembna na podlagi do sedaj označenih takih sporočil. V začetku bo verjetno treba kakšno označiti še ročno, a se bo sistem s časom izboljševal.",
@@ -303,7 +298,6 @@ OC.L10N.register(
     "Collapse folders" : "Zloži mape",
     "_{total} message_::_{total} messages_" : ["{total} sporočilo","{total} sporočili","{total} sporočila","{total} sporočil"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neprebrano od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebranih od skupno {total}"],
-    "Loading …" : "Poteka nalaganje …",
     "All messages in mailbox will be deleted." : "Vsa sporočila v poštnem predalu bodo izbrisana.",
     "Clear mailbox {name}" : "Počisti poštni predal {name}",
     "The folder and all messages in it will be deleted." : "Mapa in vsa sporočila bodo izbrisana.",
@@ -347,7 +341,6 @@ OC.L10N.register(
     "Add to Contact" : "Dodaj k stiku",
     "New Contact" : "Nov stik",
     "Copy to clipboard" : "Kopiraj v odložišče",
-    "Contact name …" : "Ime stika …",
     "Add" : "Dodaj",
     "Show less" : "Pokaži manj",
     "Show more" : "Pokaži več",
@@ -374,13 +367,11 @@ OC.L10N.register(
     "Save sieve settings" : "Shrani nastavitve sieve",
     "The syntax seems to be incorrect:" : "Skladnja je videti nepravilna:",
     "Save sieve script" : "Shrani skript sieve",
-    "Signature …" : "Podpis ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Nastavljen podpis je večji od 2 MB. Velikost lahko vpliva na delovanje urejevalnika.",
     "Save signature" : "Shrani podpis",
     "Place signature above quoted text" : "Postavi podpis nad navedeno besedilo.",
     "Message source" : "Vir sporočila",
     "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
-    "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
     "Delete tag" : "Izbriši oznako",
     "Set tag" : "Nastavi oznako",
     "Unset tag" : "Odstrani oznako",
@@ -389,7 +380,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Prišlo je do napake, oznake ni mogoče ustvariti.",
     "Add default tags" : "Dodaj privzete oznake",
     "Add tag" : "Dodaj oznako",
-    "Saving tag …" : "Poteka shranjevanje ozake ...",
     "Task created" : "Naloga je ustvarjena",
     "Could not create task" : "Naloge ni mogoče ustvariti",
     "No calendars with task list support" : "Koledar s podporo seznama nalog",
@@ -548,6 +538,16 @@ OC.L10N.register(
     "Data collection consent" : "Strinjanje z zbiranjem podatkov",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
     "Trusted senders" : "Zaupanja vredni pošiljatelji",
-    "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME"
+    "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
+    "Contact or email address …" : "Stik ali elektronski naslov ...",
+    "Subject …" : "Zadeva ...",
+    "Write message …" : "Besedilo sporočila ...",
+    "Saving draft …" : "Poteka shranjevanje osnutka ...",
+    "Loading messages …" : "Poteka nalaganje sporočil ...",
+    "Loading …" : "Poteka nalaganje …",
+    "Contact name …" : "Ime stika …",
+    "Signature …" : "Podpis ...",
+    "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
+    "Saving tag …" : "Poteka shranjevanje ozake ..."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
