@@ -76,7 +76,6 @@ OC.L10N.register(
     "Register" : "Registrera",
     "Security" : "Säkerhet",
     "Manage certificates" : "Hantera certifikat",
-    "About" : "Om",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Compose new message" : "Skapa nytt meddelande",
     "Newer message" : "Nyare meddelande",
@@ -88,21 +87,19 @@ OC.L10N.register(
     "Search" : "Sök",
     "Send" : "Skicka",
     "Refresh" : "Uppdatera",
+    "About" : "Om",
     "Ok" : "Ok",
     "Send later" : "Skicka senare",
     "Message {id} could not be found" : "Meddelandet {id} hittades inte",
     "From" : "Från",
     "Select account" : "Välj konto",
     "To" : "Till",
-    "Contact or email address …" : "Kontakt eller e-postadress …",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Ämne",
-    "Subject …" : "Ämne …",
     "This message came from a noreply address so your reply will probably not be read." : "Det här meddelandet kom från en noreply adress så ditt svar kommer förmodligen inte att läsas.",
     "The following recipients do not have a PGP key: {recipients}." : "Följande mottagare har ingen PGP-nyckel: {recipients}.",
-    "Write message …" : "Skriv meddelande ...",
-    "Saving draft …" : "Sparar utkast ...",
+    "Write message …" : "Skriv meddelande …",
     "Error saving draft" : "Kunde inte spara utkast",
     "Draft saved" : "Utkast sparat",
     "Save draft" : "Spara utkast",
@@ -189,7 +186,6 @@ OC.L10N.register(
     "Today" : "Idag",
     "Yesterday" : "I går",
     "Last week" : "Förra veckan",
-    "Loading messages …" : "Läser in meddelanden …",
     "Choose target folder" : "Välj målmapp",
     "No more submailboxes in here" : "Inga fler undermappar här",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
@@ -237,7 +233,7 @@ OC.L10N.register(
     "Collapse folders" : "Dölj mappar",
     "_{total} message_::_{total} messages_" : ["{total} meddelande","{total} meddelanden"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} av {total} oläst","{unread} av {total} oläst"],
-    "Loading …" : "Läser in ...",
+    "Loading …" : "Laddar …",
     "The folder and all messages in it will be deleted." : "Denna mapp och alla meddelanden i den kommer att raderas.",
     "Delete folder" : "Radera mapp",
     "Delete folder {name}" : "Ta bort mapp {name}",
@@ -267,7 +263,6 @@ OC.L10N.register(
     "Add to Contact" : "Lägg till i Kontakter",
     "New Contact" : "Ny kontakt",
     "Copy to clipboard" : "Kopiera till urklipp",
-    "Contact name …" : "Kontaktnamn …",
     "Add" : "Lägg till",
     "Show less" : "Visa mindre",
     "Show more" : "Visa mer",
@@ -282,7 +277,6 @@ OC.L10N.register(
     "Select tags" : "Välj taggar",
     "Last 7 days" : "Senaste 7 dagarna",
     "Custom" : "Anpassad",
-    "Signature …" : "Signatur …",
     "Save signature" : "Spara signatur",
     "Place signature above quoted text" : "Placera signaturen ovanför citerad text",
     "Message source" : "Meddelandekälla",
@@ -292,7 +286,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Ett fel uppstod, kunde inte spara taggen.",
     "Add default tags" : "Lägg till standardtaggar",
     "Add tag" : "Lägg till tagg",
-    "Saving tag …" : "Sparar tagg …",
     "Could not load your message thread" : "Det gick inte att ladda meddelandetråden",
     "Not found" : "Hittades inte",
     "Reply all" : "Svara alla",
@@ -319,6 +312,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} från {depStation} till {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tåg från {depStation} till {arrStation}",
     "Train" : "Tåg",
+    "Stop" : "Avsluta",
     "Recipient" : "Mottagare",
     "Delete filter" : "Ta bort filter",
     "Help" : "Hjälp",
@@ -391,6 +385,15 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon som profilbild",
     "Register as application for mail links" : "Registrera som app för e-postlänkar",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
-    "Trusted senders" : "Betrodda avsändare"
+    "Trusted senders" : "Betrodda avsändare",
+    "Contact or email address …" : "Kontakt eller e-postadress …",
+    "Subject …" : "Ämne …",
+    "Write message …" : "Skriv meddelande ...",
+    "Saving draft …" : "Sparar utkast ...",
+    "Loading messages …" : "Läser in meddelanden …",
+    "Loading …" : "Läser in ...",
+    "Contact name …" : "Kontaktnamn …",
+    "Signature …" : "Signatur …",
+    "Saving tag …" : "Sparar tagg …"
 },
 "nplurals=2; plural=(n != 1);");
