@@ -55,7 +55,6 @@ OC.L10N.register(
     "Oldest first" : "Cũ nhất trước",
     "Register" : "Đăng ký",
     "Security" : "Bảo mật",
-    "About" : "Giới thiệu",
     "Keyboard shortcuts" : "Phím tắt",
     "Compose new message" : "Soạn tin nhăn mơi",
     "Newer message" : "Tin nhắn mới hơn",
@@ -67,18 +66,15 @@ OC.L10N.register(
     "Search" : "Tìm",
     "Send" : "Gởi",
     "Refresh" : "Làm mới",
+    "About" : "Giới thiệu",
     "Ok" : "Đồng ý",
     "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
     "From" : "Từ",
     "Select account" : "Chọn tài khoản",
     "To" : "Tới",
-    "Contact or email address …" : "Địa chỉ liên hệ hoặc thư điện tử …",
     "Subject" : "Chủ đề",
-    "Subject …" : "Chủ đề …",
     "This message came from a noreply address so your reply will probably not be read." : "Thư này đến từ một địa chỉ không trả lời nên có thể sẽ không đọc được thư trả lời của bạn.",
     "The following recipients do not have a PGP key: {recipients}." : "Những người nhận sau không có khóa PGP: {recipients}.",
-    "Write message …" : "Viết tin nhắn …",
-    "Saving draft …" : "Đang lưu bản nháp …",
     "Draft saved" : "Bản nháp đã được lưu",
     "Enable formatting" : "Bật định dạng",
     "Upload attachment" : "Tải lên một đính kèm",
@@ -176,7 +172,6 @@ OC.L10N.register(
     "Move down" : "Di chuyển xuống",
     "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
-    "Loading …" : "Đang tải...",
     "Delete folder" : "Xoá thư mục",
     "An error occurred, unable to rename the mailbox." : "Đã xảy ra lỗi, không thể đổi tên hộp thư.",
     "Mark all as read" : "Đánh dấu tất cả như đã ",
@@ -193,7 +188,6 @@ OC.L10N.register(
     "Add to Contact" : "Thêm liên hệ",
     "New Contact" : "ĐỊa chỉ liên hệ mới",
     "Copy to clipboard" : "Sao chép vào clipboard",
-    "Contact name …" : "Tên người liên hệ …",
     "Add" : "Thêm",
     "Clear" : "Xóa",
     "Close" : "Đóng",
@@ -208,7 +202,6 @@ OC.L10N.register(
     "Sieve Password" : "Mật khẩu Sieve",
     "Save sieve settings" : "Lưu cài đặt sieve",
     "Save sieve script" : "Lưu sieve script",
-    "Signature …" : "Chữ ký …",
     "Save signature" : "Lưu chữ ký",
     "Message source" : "Nguồn tin nhắn",
     "Tag already exists" : "Thẻ đã tồn tại",
@@ -289,6 +282,13 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Sử dụng hình đại diện Gravatar và favicon",
     "Register as application for mail links" : "Đăng ký làm ứng dụng cho các liên kết gửi thư",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
-    "Trusted senders" : "Người gửi đáng tin cậy"
+    "Trusted senders" : "Người gửi đáng tin cậy",
+    "Contact or email address …" : "Địa chỉ liên hệ hoặc thư điện tử …",
+    "Subject …" : "Chủ đề …",
+    "Write message …" : "Viết tin nhắn …",
+    "Saving draft …" : "Đang lưu bản nháp …",
+    "Loading …" : "Đang tải...",
+    "Contact name …" : "Tên người liên hệ …",
+    "Signature …" : "Chữ ký …"
 },
 "nplurals=1; plural=0;");
