@@ -119,6 +119,7 @@ class MailManager implements IMailManager {
 		$this->threadMapper = $threadMapper;
 	}
 
+	#[\Override]
 	public function getMailbox(string $uid, int $id): Mailbox {
 		try {
 			return $this->mailboxMapper->findByUid($id, $uid);
@@ -133,6 +134,7 @@ class MailManager implements IMailManager {
 	 * @return Mailbox[]
 	 * @throws ServiceException
 	 */
+	#[\Override]
 	public function getMailboxes(Account $account): array {
 		$this->mailboxSync->sync($account, $this->logger);
 
@@ -146,10 +148,11 @@ class MailManager implements IMailManager {
 	 * @return Mailbox
 	 * @throws ServiceException
 	 */
+	#[\Override]
 	public function createMailbox(Account $account, string $name): Mailbox {
 		$client = $this->imapClientFactory->getClient($account);
 		try {
-			$folder = $this->folderMapper->createFolder($client, $account, $name);
+			$folder = $this->folderMapper->createFolder($client, $name);
 			$this->folderMapper->fetchFolderAcls([$folder], $client);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
@@ -179,6 +182,7 @@ class MailManager implements IMailManager {
 	 * @throws ServiceException
 	 * @throws SmimeDecryptException
 	 */
+	#[\Override]
 	public function getImapMessage(Horde_Imap_Client_Socket $client,
 		Account $account,
 		Mailbox $mailbox,
@@ -231,14 +235,17 @@ class MailManager implements IMailManager {
 		}
 	}
 
+	#[\Override]
 	public function getThread(Account $account, string $threadRootId): array {
 		return $this->dbMessageMapper->findThread($account, $threadRootId);
 	}
 
+	#[\Override]
 	public function getMessageIdForUid(Mailbox $mailbox, $uid): ?int {
 		return $this->dbMessageMapper->getIdForUid($mailbox, $uid);
 	}
 
+	#[\Override]
 	public function getMessage(string $uid, int $id): Message {
 		return $this->dbMessageMapper->findByUserId($uid, $id);
 	}
@@ -253,6 +260,7 @@ class MailManager implements IMailManager {
 	 *
 	 * @throws ServiceException
 	 */
+	#[\Override]
 	public function getSource(Horde_Imap_Client_Socket $client,
 		Account $account,
 		string $mailbox,
@@ -280,6 +288,7 @@ class MailManager implements IMailManager {
 	 * @return ?int the new UID (or null if couldn't be determined)
 	 * @throws ServiceException
 	 */
+	#[\Override]
 	public function moveMessage(Account $sourceAccount,
 		string $sourceFolderId,
 		int $uid,
@@ -316,6 +325,7 @@ class MailManager implements IMailManager {
 	 * @throws ServiceException
 	 * @todo evaluate if we should sync mailboxes first
 	 */
+	#[\Override]
 	public function deleteMessage(Account $account,
 		string $mailboxId,
 		int $messageUid): void {
@@ -340,6 +350,7 @@ class MailManager implements IMailManager {
 	 *
 	 * @todo evaluate if we should sync mailboxes first
 	 */
+	#[\Override]
 	public function deleteMessageWithClient(
 		Account $account,
 		Mailbox $mailbox,
@@ -403,6 +414,7 @@ class MailManager implements IMailManager {
 		}
 	}
 
+	#[\Override]
 	public function markFolderAsRead(Account $account, Mailbox $mailbox): void {
 		$client = $this->imapClientFactory->getClient($account);
 		try {
@@ -412,6 +424,7 @@ class MailManager implements IMailManager {
 		}
 	}
 
+	#[\Override]
 	public function updateSubscription(Account $account, Mailbox $mailbox, bool $subscribed): Mailbox {
 		/**
 		 * 1. Change subscription on IMAP
@@ -440,6 +453,7 @@ class MailManager implements IMailManager {
 		return $this->mailboxMapper->find($account, $mailbox->getName());
 	}
 
+	#[\Override]
 	public function enableMailboxBackgroundSync(Mailbox $mailbox,
 		bool $syncInBackground): Mailbox {
 		$mailbox->setSyncInBackground($syncInBackground);
@@ -447,6 +461,7 @@ class MailManager implements IMailManager {
 		return $this->mailboxMapper->update($mailbox);
 	}
 
+	#[\Override]
 	public function flagMessage(Account $account, string $mailbox, int $uid, string $flag, bool $value): void {
 		try {
 			$mb = $this->mailboxMapper->find($account, $mailbox);
@@ -546,6 +561,7 @@ class MailManager implements IMailManager {
 	 *
 	 * @link https://github.com/nextcloud/mail/issues/25
 	 */
+	#[\Override]
 	public function tagMessage(Account $account, string $mailbox, Message $message, Tag $tag, bool $value): void {
 		try {
 			$mb = $this->mailboxMapper->find($account, $mailbox);
@@ -566,6 +582,7 @@ class MailManager implements IMailManager {
 	 * @return Quota|null
 	 * @see https://tools.ietf.org/html/rfc2087
 	 */
+	#[\Override]
 	public function getQuota(Account $account): ?Quota {
 		/**
 		 * Get all the quotas roots of the user's mailboxes
@@ -611,6 +628,7 @@ class MailManager implements IMailManager {
 		);
 	}
 
+	#[\Override]
 	public function renameMailbox(Account $account, Mailbox $mailbox, string $name): Mailbox {
 		/*
 		 * 1. Rename on IMAP
@@ -647,6 +665,7 @@ class MailManager implements IMailManager {
 	 *
 	 * @throws ServiceException
 	 */
+	#[\Override]
 	public function deleteMailbox(Account $account,
 		Mailbox $mailbox): void {
 		$client = $this->imapClientFactory->getClient($account);
@@ -669,6 +688,7 @@ class MailManager implements IMailManager {
 	 * @throws Horde_Imap_Client_Exception_NoSupportExtension
 	 * @throws ServiceException
 	 */
+	#[\Override]
 	public function clearMailbox(Account $account,
 		Mailbox $mailbox): void {
 		$client = $this->imapClientFactory->getClient($account);
@@ -697,6 +717,7 @@ class MailManager implements IMailManager {
 	 * @param Message $message
 	 * @return Attachment[]
 	 */
+	#[\Override]
 	public function getMailAttachments(Account $account, Mailbox $mailbox, Message $message): array {
 		$client = $this->imapClientFactory->getClient($account);
 		try {
@@ -724,6 +745,7 @@ class MailManager implements IMailManager {
 	 * @throws ServiceException
 	 * @throws Horde_Mime_Exception
 	 */
+	#[\Override]
 	public function getMailAttachment(Account $account,
 		Mailbox $mailbox,
 		Message $message,
@@ -748,6 +770,7 @@ class MailManager implements IMailManager {
 	 * @return Tag
 	 * @throws ClientException
 	 */
+	#[\Override]
 	public function getTagByImapLabel(string $imapLabel, string $userId): Tag {
 		try {
 			return $this->tagMapper->getTagByImapLabel($imapLabel, $userId);
@@ -786,7 +809,7 @@ class MailManager implements IMailManager {
 		if (in_array("\*", $capabilities['permflags']) || in_array($flag, $capabilities['permflags'])) {
 			return [$flag];
 		}
-		
+
 		return [];
 	}
 
@@ -797,6 +820,7 @@ class MailManager implements IMailManager {
 	 * @param string $mailbox
 	 * @return boolean
 	 */
+	#[\Override]
 	public function isPermflagsEnabled(Horde_Imap_Client_Socket $client, Account $account, string $mailbox): bool {
 		try {
 			$capabilities = $client->status($mailbox, Horde_Imap_Client::STATUS_PERMFLAGS);
@@ -810,6 +834,7 @@ class MailManager implements IMailManager {
 		return (is_array($capabilities) === true && array_key_exists('permflags', $capabilities) === true && in_array("\*", $capabilities['permflags'], true) === true);
 	}
 
+	#[\Override]
 	public function createTag(string $displayName, string $color, string $userId): Tag {
 		try {
 			$imapLabel = $this->imapFlag->create($displayName);
@@ -833,6 +858,7 @@ class MailManager implements IMailManager {
 		return $this->tagMapper->insert($tag);
 	}
 
+	#[\Override]
 	public function updateTag(int $id, string $displayName, string $color, string $userId): Tag {
 		try {
 			$tag = $this->tagMapper->getTagForUser($id, $userId);
@@ -846,6 +872,7 @@ class MailManager implements IMailManager {
 		return $this->tagMapper->update($tag);
 	}
 
+	#[\Override]
 	public function deleteTag(int $id, string $userId, array $accounts) :Tag {
 		try {
 			$tag = $this->tagMapper->getTagForUser($id, $userId);
@@ -859,6 +886,7 @@ class MailManager implements IMailManager {
 		return $this->tagMapper->delete($tag);
 	}
 
+	#[\Override]
 	public function deleteTagForAccount(int $id, string $userId, Tag $tag, Account $account) :void {
 		try {
 			$messageTags = $this->messageTagsMapper->getMessagesByTag($id);
@@ -893,6 +921,7 @@ class MailManager implements IMailManager {
 		}
 	}
 
+	#[\Override]
 	public function moveThread(Account $srcAccount, Mailbox $srcMailbox, Account $dstAccount, Mailbox $dstMailbox, string $threadRootId): array {
 		$mailAccount = $srcAccount->getMailAccount();
 		$messageInTrash = $srcMailbox->getId() === $mailAccount->getTrashMailboxId();
@@ -929,6 +958,7 @@ class MailManager implements IMailManager {
 	 * @throws ClientException
 	 * @throws ServiceException
 	 */
+	#[\Override]
 	public function deleteThread(Account $account, Mailbox $mailbox, string $threadRootId): void {
 		$mailAccount = $account->getMailAccount();
 		$messageInTrash = $mailbox->getId() === $mailAccount->getTrashMailboxId();
@@ -956,6 +986,7 @@ class MailManager implements IMailManager {
 	/**
 	 * @return Message[]
 	 */
+	#[\Override]
 	public function getByMessageId(Account $account, string $messageId): array {
 		return $this->dbMessageMapper->findByMessageId($account, $messageId);
 	}
